@@ -1,13 +1,7 @@
 #' Calculate graph global, local, or nodal efficiency
 #'
 #' This function calculates the global efficiency of a graph or the local or
-#' nodal efficiency of each vertex of a graph. The global efficiency is equal
-#' to the mean of all nodal efficiencies.
-#'
-#' Global efficiency for graph \emph{G} with \emph{N} vertices is:
-#' \deqn{E_{global}(G) = \frac{1}{N(N-1)} \sum_{i \ne j \in G} \frac{1}{d_{ij}}}
-#' where \eqn{d_{ij}} is the shortest path length between vertices \emph{i} and
-#' \emph{j}.
+#' nodal efficiency of each vertex of a graph.
 #'
 #' Local efficiency for vertex \emph{i} is:
 #' \deqn{E_{local}(i) = \frac{1}{N} \sum_{i \in G} E_{global}(G_i)}
@@ -17,6 +11,12 @@
 #' Nodal efficiency for vertex \emph{i} is:
 #' \deqn{E_{nodal}(i) = \frac{1}{N-1} \sum_{j \in G} \frac{1}{d_{ij}}}
 #'
+#' Global efficiency for graph \emph{G} with \emph{N} vertices is:
+#' \deqn{E_{global}(G) = \frac{1}{N(N-1)} \sum_{i \ne j \in G} \frac{1}{d_{ij}}}
+#' where \eqn{d_{ij}} is the shortest path length between vertices \emph{i} and
+#' \emph{j}. Alternatively, global efficiency is equal to the mean of all nodal
+#' efficiencies.
+#'
 #' @param g An \code{igraph} graph object
 #' @param type Character string; either \code{local}, \code{nodal}, or
 #'   \code{global} (default: \code{local})
@@ -28,14 +28,17 @@
 #' @param A Numeric matrix; the (weighted or unweighted) adjacency matrix of the
 #'   input graph (default: \code{NULL})
 #' @export
+#' @importFrom Matrix rowSums
 #'
-#' @return A numeric vector of the local efficiencies for each vertex of the
-#'   graph (if \emph{type} is \code{local|nodal}) or a single number (if
-#'   \emph{type} is \code{global}).
+#' @return A numeric vector of the efficiencies for each vertex of the graph
+#'   (if \emph{type} is \code{local|nodal}) or a single number (if \emph{type}
+#'   is \code{global}).
 #'
 #' @author Christopher G. Watson, \email{cgwatson@@bu.edu}
 #' @references Latora V., Marchiori M. (2001) \emph{Efficient behavior of
-#' small-world networks}. Phys Rev Lett, 87.19:198701.
+#'   small-world networks}. Phys Rev Lett, 87.19:198701.
+#' @references Latora V., Marchiori M. (2003) \emph{Economic small-world
+#'   behavior in weighted networks}. Eur Phys J B, 32:249-263.
 
 efficiency <- function(g, type=c('local', 'nodal', 'global'), weights=NULL,
                        use.parallel=TRUE, A=NULL) {
@@ -53,12 +56,6 @@ efficiency <- function(g, type=c('local', 'nodal', 'global'), weights=NULL,
 
   type <- match.arg(type)
   if (type == 'local') {
-    if ('degree' %in% vertex_attr_names(g)) {
-      degs <- V(g)$degree
-    } else {
-      degs <- degree(g)
-    }
-
     if (is.null(weights)) {
       if (is.null(A)) A <- as_adj(g, names=FALSE, attr='weight')
       weighted <- TRUE
@@ -66,8 +63,8 @@ efficiency <- function(g, type=c('local', 'nodal', 'global'), weights=NULL,
       A <- as_adj(g, names=FALSE, sparse=FALSE)
       weighted <- NULL
     }
-    eff <- rep(0, length(degs))
-    nodes <- which(degs > 1)
+    eff <- rep(0, nrow(A))
+    nodes <- which(rowSums((A > 0) + 0) > 1)
     X <- apply(A, 1, function(x) which(x > 0))
 
     if (length(nodes) > 0) {
@@ -84,20 +81,11 @@ efficiency <- function(g, type=c('local', 'nodal', 'global'), weights=NULL,
       }
     }
   } else {
-    Nv <- vcount(g)
-    eff <- apply(distances(g, weights=weights), 2, function(x)
-                 sum(1 / x[x != 0]) / (Nv - 1))
+    D <- distances(g, weights=weights)
+    Nv <- nrow(D)
+    Dinv <- 1 / D
+    eff <- colSums(Dinv * is.finite(Dinv), na.rm=T) / (Nv - 1)
     if (type == 'global') eff <- sum(eff) / length(eff)
   }
   return(eff)
 }
-
-#' @inheritParams efficiency
-#' @export
-#' @rdname efficiency
-
-graph.efficiency <- function(g, type=c('local', 'nodal', 'global'), weights=NULL,
-                             use.parallel=TRUE, A=NULL) {
-  .Deprecated('efficiency')
-  efficiency(g, type=type, weights=weights, use.parallel=use.parallel, A=A)
-}
